@@ -12,7 +12,13 @@ from types import TracebackType
 
 from rich.console import Console
 
+from crackerjack.core.resource_manager import (
+    ResourceManager,
+    register_global_resource_manager,
+)
+from crackerjack.core.websocket_lifecycle import NetworkResourceManager
 from crackerjack.core.workflow_orchestrator import WorkflowOrchestrator
+from crackerjack.services.secure_path_utils import SecurePathValidator
 
 from .cache import ErrorCache
 from .rate_limiter import RateLimitConfig, RateLimitMiddleware
@@ -27,7 +33,7 @@ class BatchedStateSaver:
         self._pending_saves: dict[str, t.Callable[[], None]] = {}
         self._last_save_time: dict[str, float] = {}
 
-        self._save_task: asyncio.Task | None = None
+        self._save_task: asyncio.Task[None] | None = None
         self._running = False
         self._lock = asyncio.Lock()
 
@@ -79,7 +85,7 @@ class BatchedStateSaver:
         ready_saves = []
 
         async with self._lock:
-            for save_id, last_time in list(self._last_save_time.items()):
+            for save_id, last_time in list[t.Any](self._last_save_time.items()):
                 if now - last_time >= self.debounce_delay:
                     ready_saves.append(save_id)
 
@@ -100,7 +106,7 @@ class BatchedStateSaver:
 
     async def _flush_saves(self) -> None:
         async with self._lock:
-            save_ids = list(self._pending_saves.keys())
+            save_ids = list[t.Any](self._pending_saves.keys())
 
         if save_ids:
             await self._execute_saves(save_ids)
@@ -123,13 +129,31 @@ class MCPServerConfig:
     state_dir: Path | None = None
     cache_dir: Path | None = None
 
+    def __post_init__(self) -> None:
+        self.project_path = SecurePathValidator.validate_safe_path(self.project_path)
+
+        if self.progress_dir:
+            self.progress_dir = SecurePathValidator.validate_safe_path(
+                self.progress_dir
+            )
+
+        if self.state_dir:
+            self.state_dir = SecurePathValidator.validate_safe_path(self.state_dir)
+
+        if self.cache_dir:
+            self.cache_dir = SecurePathValidator.validate_safe_path(self.cache_dir)
+
 
 class MCPServerContext:
     def __init__(self, config: MCPServerConfig) -> None:
         self.config = config
 
+        self.resource_manager = ResourceManager()
+        self.network_manager = NetworkResourceManager()
+        register_global_resource_manager(self.resource_manager)
+
         self.console: Console | None = None
-        self.cli_runner = None
+        self.cli_runner: WorkflowOrchestrator | None = None
         self.state_manager: StateManager | None = None
         self.error_cache: ErrorCache | None = None
         self.rate_limiter: RateLimitMiddleware | None = None
@@ -148,55 +172,167 @@ class MCPServerContext:
         )
         self._websocket_process_lock = asyncio.Lock()
         self._websocket_cleanup_registered = False
-        self._websocket_health_check_task: asyncio.Task | None = None
+        self._websocket_health_check_task: asyncio.Task[None] | None = None
 
         self._initialized = False
         self._startup_tasks: list[t.Callable[[], t.Awaitable[None]]] = []
         self._shutdown_tasks: list[t.Callable[[], t.Awaitable[None]]] = []
 
+    async def _auto_setup_git_working_directory(self) -> None:
+        """Auto-detect and setup git working directory for enhanced DX."""
+        try:
+            git_root = await self._detect_git_repository()
+            if git_root:
+                await self._log_git_detection(git_root)
+
+        except Exception as e:
+            self._handle_git_setup_failure(e)
+
+    async def _detect_git_repository(self) -> Path | None:
+        """Detect if we're in a git repository and return the root path."""
+
+        current_dir = Path.cwd()
+
+        # Check if we're in a git repository
+        if not self._is_git_repository(current_dir):
+            return None
+
+        return self._get_git_root_directory(current_dir)
+
+    def _is_git_repository(self, current_dir: Path) -> bool:
+        """Check if the current directory is within a git repository."""
+        import subprocess
+
+        git_check = subprocess.run(
+            ["git", "rev-parse", "--is-inside-work-tree"],
+            capture_output=True,
+            text=True,
+            cwd=current_dir,
+        )
+        return git_check.returncode == 0
+
+    def _get_git_root_directory(self, current_dir: Path) -> Path | None:
+        """Get the git repository root directory."""
+        import subprocess
+
+        git_root_result = subprocess.run(
+            ["git", "rev-parse", "--show-toplevel"],
+            capture_output=True,
+            text=True,
+            cwd=current_dir,
+        )
+
+        if git_root_result.returncode == 0:
+            git_root = Path(git_root_result.stdout.strip())
+            return git_root if git_root.exists() else None
+        return None
+
+    async def _log_git_detection(self, git_root: Path) -> None:
+        """Log git repository detection to stderr and console."""
+
+        # Log to stderr for Claude to see
+        self._log_to_stderr(git_root)
+
+        # Log to console if available
+        self._log_to_console(git_root)
+
+    def _log_to_stderr(self, git_root: Path) -> None:
+        """Log git detection messages to stderr."""
+        import sys
+
+        print(
+            f"📍 Crackerjack MCP: Git repository detected at {git_root}",
+            file=sys.stderr,
+        )
+        print(
+            f"💡 Tip: Auto-setup git working directory with: git_set_working_dir('{git_root}')",
+            file=sys.stderr,
+        )
+
+    def _log_to_console(self, git_root: Path) -> None:
+        """Log git detection messages to console if available."""
+        if self.console:
+            self.console.print(f"🔧 Auto-detected git repository: {git_root}")
+            self.console.print(
+                f"💡 Recommend: Use `mcp__git__git_set_working_dir` with path='{git_root}'"
+            )
+
+    def _handle_git_setup_failure(self, error: Exception) -> None:
+        """Handle git setup failure with graceful fallback."""
+        if self.console:
+            self.console.print(
+                f"[dim]Git auto-setup failed (non-critical): {error}[/dim]"
+            )
+
     async def initialize(self) -> None:
         if self._initialized:
             return
 
         try:
-            if self.config.stdio_mode:
-                null_file = io.StringIO()
-                self.console = Console(file=null_file, force_terminal=False)
-            else:
-                self.console = Console(force_terminal=True)
-
-            self.progress_dir.mkdir(exist_ok=True)
-
-            self.cli_runner = WorkflowOrchestrator(
-                console=self.console,
-                pkg_path=self.config.project_path,
-            )
-
-            self.state_manager = StateManager(
-                self.config.state_dir or Path.home() / ".cache" / "crackerjack-mcp",
-                self.batched_saver,
-            )
-
-            self.error_cache = ErrorCache(
-                self.config.cache_dir or Path.home() / ".cache" / "crackerjack-mcp",
-            )
-
-            self.rate_limiter = RateLimitMiddleware(self.config.rate_limit_config)
-
-            await self.batched_saver.start()
-
-            for task in self._startup_tasks:
-                await task()
-
+            await self._perform_initialization_sequence()
             self._initialized = True
 
         except Exception as e:
-            self.cli_runner = None
-            self.state_manager = None
-            self.error_cache = None
-            self.rate_limiter = None
-            msg = f"Failed to initialize MCP server context: {e}"
-            raise RuntimeError(msg) from e
+            self._handle_initialization_failure(e)
+
+    async def _perform_initialization_sequence(self) -> None:
+        """Perform the complete initialization sequence."""
+        self._setup_console()
+        self._setup_directories()
+        await self._initialize_components()
+        await self._finalize_initialization()
+
+    def _handle_initialization_failure(self, error: Exception) -> None:
+        """Handle initialization failure with cleanup and error propagation."""
+        self._cleanup_failed_initialization()
+        msg = f"Failed to initialize MCP server context: {error}"
+        raise RuntimeError(msg) from error
+
+    def _setup_console(self) -> None:
+        """Setup console based on configuration mode."""
+        if self.config.stdio_mode:
+            null_file = io.StringIO()
+            self.console = Console(file=null_file, force_terminal=False)
+        else:
+            self.console = Console(force_terminal=True)
+
+    def _setup_directories(self) -> None:
+        """Setup required directories."""
+        self.progress_dir.mkdir(exist_ok=True)
+
+    async def _initialize_components(self) -> None:
+        """Initialize all service components."""
+        self.cli_runner = WorkflowOrchestrator(
+            console=self.console,
+            pkg_path=self.config.project_path,
+        )
+
+        self.state_manager = StateManager(
+            self.config.state_dir or Path.home() / ".cache" / "crackerjack-mcp",
+            self.batched_saver,
+        )
+
+        self.error_cache = ErrorCache(
+            self.config.cache_dir or Path.home() / ".cache" / "crackerjack-mcp",
+        )
+
+        self.rate_limiter = RateLimitMiddleware(self.config.rate_limit_config)
+        await self.batched_saver.start()
+
+    async def _finalize_initialization(self) -> None:
+        """Complete initialization with optional setup and startup tasks."""
+        # Auto-setup git working directory for enhanced DX
+        await self._auto_setup_git_working_directory()
+
+        for task in self._startup_tasks:
+            await task()
+
+    def _cleanup_failed_initialization(self) -> None:
+        """Cleanup components after failed initialization."""
+        self.cli_runner = None
+        self.state_manager = None
+        self.error_cache = None
+        self.rate_limiter = None
 
     async def shutdown(self) -> None:
         if not self._initialized:
@@ -222,6 +358,22 @@ class MCPServerContext:
 
         await self.batched_saver.stop()
 
+        try:
+            await self.network_manager.cleanup_all()
+        except Exception as e:
+            if self.console:
+                self.console.print(
+                    f"[yellow]Warning: Network resource cleanup error: {e}[/yellow]"
+                )
+
+        try:
+            await self.resource_manager.cleanup_all()
+        except Exception as e:
+            if self.console:
+                self.console.print(
+                    f"[yellow]Warning: Resource cleanup error: {e}[/yellow]"
+                )
+
         self._initialized = False
 
     def add_startup_task(self, task: t.Callable[[], t.Awaitable[None]]) -> None:
@@ -241,9 +393,9 @@ class MCPServerContext:
             uuid.UUID(job_id)
             return True
 
-        import re
+        from crackerjack.services.regex_patterns import is_valid_job_id
 
-        if not re.match(r"^[a-zA-Z0-9_-]+$", job_id):
+        if not is_valid_job_id(job_id):
             return False
 
         if ".." in job_id or "/" in job_id or "\\" in job_id:
@@ -266,21 +418,31 @@ class MCPServerContext:
             if await self._check_existing_websocket_server():
                 return True
 
-            if self.console:
-                self.console.print(
-                    f"🚀 Starting WebSocket server on localhost:{self.websocket_server_port}...",
-                )
+            self._print_websocket_startup_message()
+            return await self._attempt_websocket_startup()
 
-            try:
-                await self._spawn_websocket_process()
-                await self._register_websocket_cleanup()
-                return await self._wait_for_websocket_startup()
+    def _print_websocket_startup_message(self) -> None:
+        """Print websocket server startup message."""
+        if self.console:
+            self.console.print(
+                f"🚀 Starting WebSocket server on localhost: {self.websocket_server_port}...",
+            )
 
-            except Exception as e:
-                if self.console:
-                    self.console.print(f"❌ Failed to start WebSocket server: {e}")
-                await self._cleanup_dead_websocket_process()
-                return False
+    async def _attempt_websocket_startup(self) -> bool:
+        """Attempt to start the websocket server with error handling."""
+        try:
+            await self._spawn_websocket_process()
+            await self._register_websocket_cleanup()
+            return await self._wait_for_websocket_startup()
+        except Exception as e:
+            await self._handle_websocket_startup_failure(e)
+            return False
+
+    async def _handle_websocket_startup_failure(self, error: Exception) -> None:
+        """Handle websocket server startup failure."""
+        if self.console:
+            self.console.print(f"❌ Failed to start WebSocket server: {error}")
+        await self._cleanup_dead_websocket_process()
 
     async def _check_existing_websocket_server(self) -> bool:
         if (
@@ -321,6 +483,12 @@ class MCPServerContext:
             start_new_session=True,
         )
 
+        if self.websocket_server_process:
+            managed_process = self.network_manager.create_subprocess(
+                self.websocket_server_process, timeout=30.0
+            )
+            await managed_process.start_monitoring()
+
     async def _register_websocket_cleanup(self) -> None:
         if not self._websocket_cleanup_registered:
             self.add_shutdown_task(self._stop_websocket_server)
@@ -336,7 +504,10 @@ class MCPServerContext:
         for _attempt in range(max_attempts):
             await asyncio.sleep(0.5)
 
-            if self.websocket_server_process.poll() is not None:
+            if (
+                self.websocket_server_process is not None
+                and self.websocket_server_process.poll() is not None
+            ):
                 return_code = self.websocket_server_process.returncode
                 if self.console:
                     self.console.print(
@@ -351,7 +522,7 @@ class MCPServerContext:
                         f"✅ WebSocket server started successfully on port {self.websocket_server_port}",
                     )
                     self.console.print(
-                        f"📊 Progress available at: ws://localhost:{self.websocket_server_port}/ws/progress/{{job_id}}",
+                        f"📊 Progress available at: ws: / / localhost: {self.websocket_server_port}/ ws / progress /{{job_id}}",
                     )
                 return True
 
@@ -365,7 +536,10 @@ class MCPServerContext:
     async def _cleanup_dead_websocket_process(self) -> None:
         if self.websocket_server_process:
             try:
-                if self.websocket_server_process.poll() is None:
+                if (
+                    self.websocket_server_process is not None
+                    and self.websocket_server_process.poll() is None
+                ):
                     self.websocket_server_process.terminate()
                     try:
                         self.websocket_server_process.wait(timeout=2)
@@ -402,7 +576,8 @@ class MCPServerContext:
         if self.console:
             self.console.print("🛑 Stopping WebSocket server...")
 
-        self.websocket_server_process.terminate()
+        if self.websocket_server_process is not None:
+            self.websocket_server_process.terminate()
 
         if await self._wait_for_graceful_termination():
             return
@@ -411,7 +586,8 @@ class MCPServerContext:
 
     async def _wait_for_graceful_termination(self) -> bool:
         try:
-            self.websocket_server_process.wait(timeout=5)
+            if self.websocket_server_process is not None:
+                self.websocket_server_process.wait(timeout=5)
             if self.console:
                 self.console.print("✅ WebSocket server stopped gracefully")
             return True
@@ -422,10 +598,12 @@ class MCPServerContext:
         if self.console:
             self.console.print("⚡ Force killing unresponsive WebSocket server...")
 
-        self.websocket_server_process.kill()
+        if self.websocket_server_process is not None:
+            self.websocket_server_process.kill()
 
         try:
-            self.websocket_server_process.wait(timeout=2)
+            if self.websocket_server_process is not None:
+                self.websocket_server_process.wait(timeout=2)
             if self.console:
                 self.console.print("💀 WebSocket server force killed")
         except subprocess.TimeoutExpired:
@@ -483,7 +661,8 @@ class MCPServerContext:
                 await self._handle_unresponsive_websocket_server()
 
     async def _handle_dead_websocket_process(self) -> None:
-        return_code = self.websocket_server_process.returncode
+        if self.websocket_server_process is not None:
+            return_code = self.websocket_server_process.returncode
         if self.console:
             self.console.print(
                 f"⚠️ WebSocket server process died (exit code: {return_code}), attempting restart...",
@@ -504,7 +683,7 @@ class MCPServerContext:
         elif self.console:
             self.console.print("❌ Failed to restart WebSocket server")
 
-    def safe_print(self, *args, **kwargs) -> None:
+    def safe_print(self, *args: t.Any, **kwargs: t.Any) -> None:
         if not self.config.stdio_mode and self.console:
             self.console.print(*args, **kwargs)
 
@@ -512,7 +691,10 @@ class MCPServerContext:
         if not self.validate_job_id(job_id):
             msg = f"Invalid job_id: {job_id}"
             raise ValueError(msg)
-        return self.progress_dir / f"job-{job_id}.json"
+
+        return SecurePathValidator.secure_path_join(
+            self.progress_dir, f"job-{job_id}.json"
+        )
 
     async def schedule_state_save(
         self,
@@ -522,7 +704,6 @@ class MCPServerContext:
         await self.batched_saver.schedule_save(save_id, save_func)
 
     def get_current_time(self) -> str:
-        """Get current timestamp as string for progress tracking."""
         import datetime
 
         return datetime.datetime.now().isoformat()
@@ -613,7 +794,7 @@ def get_rate_limiter() -> RateLimitMiddleware | None:
     return get_context().rate_limiter
 
 
-def safe_print(*args, **kwargs) -> None:
+def safe_print(*args: t.Any, **kwargs: t.Any) -> None:
     get_context().safe_print(*args, **kwargs)
 
 
